=======
History
=======

0.1.1 (2021-04-11)
------------------

Fixed bug:

* Upgrade dependency `prettytable>=2.0.0`.

0.1.0 (2020-05-11)
------------------

New feature:

* Download songs of selected types of albums (Studio Album, EP Single, Live Album, Others).
* Print error messages to help users troubleshoot.

Fixed bug:

* Fixed an issue where empty files were created when songs could not be downloaded.

0.1.0a (2020-05-10)
-------------------

* First release on PyPI.
